@@ -67,8 +67,9 @@ class AutoMapper(AutoMapperContainer):
         copy_all_unmapped_properties: bool = False,
         copy_all_unmapped_properties_exclude: Optional[List[str]] = None,
         log_level: Optional[Union[int, str]] = None,
-        enable_schema_reduction: bool = False,
+        enable_schema_pruning: bool = False,
         remove_duplicates_by_columns: Optional[List[str]] = None,
+        extension_fields: Optional[List[str]] = None,
     ):
         """
         Creates an AutoMapper
@@ -85,6 +86,7 @@ class AutoMapper(AutoMapperContainer):
         :param use_schema: apply schema to columns
         :param include_extension: By default we don't include extension elements since they take up a lot of schema.
                 If you're using extensions then set this
+        :param extension_fields: fields to enable in extensions
         :param include_null_properties: If you want to include null properties
         :param use_single_select: This is a faster way to run the AutoMapper since it will select
                 all the columns at once.
@@ -97,7 +99,7 @@ class AutoMapper(AutoMapperContainer):
         :param copy_all_unmapped_properties: copy any property that is not explicitly mapped
         :param copy_all_unmapped_properties_exclude: exclude these columns when copy_all_unmapped_properties is set
         :param logger: logger used to log informational messages
-        :param enable_schema_reduction: enables remove properties from schema that are not present in the automapper
+        :param enable_schema_pruning: remove properties from schema that are not present in the automapper
         :param remove_duplicates_by_columns: remove duplicate rows where the value of these columns match
         """
         super().__init__()
@@ -148,12 +150,13 @@ class AutoMapper(AutoMapperContainer):
         ] = copy_all_unmapped_properties_exclude
 
         self.entity_name: Optional[str] = None
-        self.enable_schema_reduction: bool = enable_schema_reduction
-        if enable_schema_reduction:
+        self.enable_schema_pruning: bool = enable_schema_pruning
+        if enable_schema_pruning:
             self.skip_schema_validation = []  # no need to filter out extensions
         self.remove_duplicates_by_columns: Optional[
             List[str]
         ] = remove_duplicates_by_columns
+        self.extension_fields: Optional[List[str]] = extension_fields
 
     def _transform_with_data_frame_single_select(
         self, df: DataFrame, source_df: DataFrame, keys: List[str]
@@ -192,11 +195,17 @@ class AutoMapper(AutoMapperContainer):
                 column_specs.extend(
                     [
                         AutoMapperDataTypeColumn(column_name)
-                        .get_column_spec(source_df=source_df, current_column=None)
+                        .get_column_spec(
+                            source_df=source_df,
+                            current_column=None,
+                            parent_columns=None,
+                        )
                         .cast(column_schema[column_name].dataType)
                         if column_name in column_schema
                         else AutoMapperDataTypeColumn(column_name).get_column_spec(
-                            source_df=source_df, current_column=None
+                            source_df=source_df,
+                            current_column=None,
+                            parent_columns=None,
                         )
                         for column_name in unmapped_properties
                         if column_name not in copy_all_unmapped_properties_exclude
@@ -206,6 +215,8 @@ class AutoMapper(AutoMapperContainer):
             if not self.drop_key_columns:
                 column_specs = [col(f"b.{c}") for c in keys] + column_specs
 
+            print(f"COLUMN SPECS --- {column_specs}")
+
             self.logger.debug(f"-------- automapper ({self.view}) column specs ------")
             self.logger.debug(self.to_debug_string(source_df=source_df))
             self.logger.debug(
@@ -654,7 +665,8 @@ class AutoMapper(AutoMapperContainer):
             include_null_properties=self.include_null_properties,
             skip_schema_validation=self.skip_schema_validation,
             skip_if_columns_null_or_empty=self.skip_if_columns_null_or_empty,
-            enable_schema_reduction=self.enable_schema_reduction,
+            enable_schema_pruning=self.enable_schema_pruning,
+            extension_fields=self.extension_fields,
         )
 
         self.entity_name = entity.__class__.__name__
