@@ -18,5 +18,5 @@ class AutoMapperColumns(AutoMapperContainer):
             include_null_properties=False,
             skip_schema_validation=[],
             skip_if_columns_null_or_empty=None,
-            enable_schema_reduction=False,
+            enable_schema_pruning=False,
         )
