@@ -18,7 +18,8 @@ class AutoMapperWithComplex(AutoMapperContainer):
         include_null_properties: bool,
         skip_schema_validation: List[str],
         skip_if_columns_null_or_empty: Optional[List[str]],
-        enable_schema_reduction: bool,
+        enable_schema_pruning: bool,
+        extension_fields: Optional[List[str]],
     ) -> None:
         """
         Create mapping for an entity
@@ -37,32 +38,15 @@ class AutoMapperWithComplex(AutoMapperContainer):
         field_names: List[str] = list(entity.get_child_mappers().keys())
         has_extension: bool = "extension" in field_names
 
-        # TODO: should detect from schema what fields are being used
-        standard_extension_fields: List[str] = [
-            "valueBoolean",
-            "valueCode",
-            "valueDate",
-            "valueDateTime",
-            "valueDecimal",
-            "valueId",
-            "valueInteger",
-            "valuePositiveInt",
-            "valueString",
-            "valueTime",
-            "valueUnsignedInt",
-            "valueUri",
-            "valueUrl",
-            "valueReference",
-            "valueCodeableConcept",
-            "valueAddress",
-        ]
         # ask entity for its schema
         schema: Union[StructType, DataType, None] = entity.get_schema(
-            include_extension=include_extension or has_extension,
-            extension_fields=standard_extension_fields,
+            include_extension=include_extension
+            or has_extension
+            or (True if extension_fields else False),
+            extension_fields=extension_fields,
         )
         column_schema: Dict[str, StructField] = {}
-        self.enable_schema_reduction: bool = enable_schema_reduction
+        self.enable_schema_pruning: bool = enable_schema_pruning
         if schema is not None and isinstance(schema, StructType):
             # if entity has an extension then ask the extension for its schema
             column_name: str
@@ -73,7 +57,7 @@ class AutoMapperWithComplex(AutoMapperContainer):
                     # since there is a column called extension then get the schema with extension
                     extension_schema = mapper.get_schema(
                         include_extension=include_extension or has_extension,
-                        extension_fields=standard_extension_fields,
+                        extension_fields=extension_fields,
                     )
                     if extension_schema is not None:
                         if (
@@ -101,5 +85,5 @@ class AutoMapperWithComplex(AutoMapperContainer):
             include_null_properties=include_null_properties or use_schema,
             skip_schema_validation=skip_schema_validation,
             skip_if_columns_null_or_empty=skip_if_columns_null_or_empty,
-            enable_schema_reduction=self.enable_schema_reduction,
+            enable_schema_pruning=self.enable_schema_pruning,
         )
