@@ -22,7 +22,7 @@ class AutoMapperWithColumnBase(AutoMapperBase):
         value: AutoMapperAnyDataType,
         column_schema: Optional[StructField],
         include_null_properties: bool,
-        enable_schema_reduction: bool,
+        enable_schema_pruning: bool,
         skip_if_columns_null_or_empty: Optional[List[str]] = None,
     ) -> None:
         """
@@ -45,20 +45,21 @@ class AutoMapperWithColumnBase(AutoMapperBase):
             self.value.include_null_properties(
                 include_null_properties=include_null_properties
             )
-        self.enable_schema_reduction: bool = enable_schema_reduction
+        self.enable_schema_pruning: bool = enable_schema_pruning
 
     def get_column_spec(self, source_df: Optional[DataFrame]) -> Column:
         # if value is an AutoMapper then ask it for its column spec
         if isinstance(self.value, AutoMapperDataTypeBase):
             child: AutoMapperDataTypeBase = self.value
             if self.column_schema:
-                self.value.set_schema(
-                    column_name=self.dst_column,
-                    column_path=self.dst_column,
-                    column_data_type=self.column_schema.dataType,
-                )
+                if self.enable_schema_pruning:
+                    self.value.set_schema(
+                        column_name=self.dst_column,
+                        column_path=self.dst_column,
+                        column_data_type=self.column_schema.dataType,
+                    )
             column_spec = child.get_column_spec(
-                source_df=source_df, current_column=None
+                source_df=source_df, current_column=None, parent_columns=None
             )
             if self.skip_if_columns_null_or_empty:
                 columns_to_check = f"b.{self.skip_if_columns_null_or_empty[0]}"  # TODO: handle more than one
@@ -68,12 +69,14 @@ class AutoMapperWithColumnBase(AutoMapperBase):
                     | col(columns_to_check).eqNullSafe(""),
                     lit(None),
                 ).otherwise(
-                    self.value.get_column_spec(source_df=source_df, current_column=None)
+                    self.value.get_column_spec(
+                        source_df=source_df, current_column=None, parent_columns=None
+                    )
                 )
             # if the type has a schema then apply it
             if self.column_schema:
                 column_data_type: DataType = self.column_schema.dataType
-                if self.enable_schema_reduction:
+                if self.enable_schema_pruning:
                     # first disable generation of null properties since we are doing schema reduction
                     self.value.include_null_properties(include_null_properties=False)
                     # second ask the mapper to reduce schema that is not used
@@ -121,7 +124,7 @@ class AutoMapperWithColumnBase(AutoMapperBase):
         if source_df and self.column_schema:
             child: AutoMapperDataTypeBase = self.value
             column_spec = child.get_column_spec(
-                source_df=source_df, current_column=None
+                source_df=source_df, current_column=None, parent_columns=None
             )
             # result = child.check_schema(
             #     parent_column=self.dst_column, source_df=source_df
