@@ -16,7 +16,6 @@ if TYPE_CHECKING:
     from spark_auto_mapper.data_types.amount import AutoMapperAmountDataType
     from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
     from spark_auto_mapper.data_types.boolean import AutoMapperBooleanDataType
-    from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
     from spark_auto_mapper.data_types.number import AutoMapperNumberDataType
     from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
     from spark_auto_mapper.data_types.datetime import AutoMapperDateTimeDataType
@@ -48,13 +47,17 @@ class AutoMapperDataTypeBase:
 
     # noinspection PyMethodMayBeStatic
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         """
         Gets the column spec for this automapper data type
 
         :param source_df: source data frame in case the automapper type needs that data to decide what to do
         :param current_column: (Optional) this is set when we are inside an array
+        :param parent_columns: Optional[List[Column]]: (Optional) a dictionary of parent columns for use inside nested arrays
         """
         raise NotImplementedError  # base classes should implement this
 
@@ -64,6 +67,7 @@ class AutoMapperDataTypeBase:
         value: "AutoMapperDataTypeBase",
         source_df: Optional[DataFrame],
         current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         """
         Gets the value for this automapper
@@ -71,10 +75,15 @@ class AutoMapperDataTypeBase:
         :param value: current value
         :param source_df: source data frame in case the automapper type needs that data to decide what to do
         :param current_column: (Optional) this is set when we are inside an array
+        :param parent_columns: (Optional) set when inside a nested lambda to access parent columns
         """
         assert isinstance(value, AutoMapperDataTypeBase)
         child: AutoMapperDataTypeBase = value
-        return child.get_column_spec(source_df=source_df, current_column=current_column)
+        return child.get_column_spec(
+            source_df=source_df,
+            current_column=current_column,
+            parent_columns=parent_columns,
+        )
 
     def include_null_properties(self, include_null_properties: bool) -> None:
         pass  # sub-classes can implement if they support this
@@ -392,8 +401,47 @@ class AutoMapperDataTypeBase:
         :return: a text automapper type
         :example: A.column("paid").to_text()
         """
+
+        from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
+
         return AutoMapperDataTypeLiteral(self, StringType())
 
+    def to_string(self: _TAutoMapperDataType) -> "AutoMapperTextLikeBase":
+        """
+        converts the value to a string type by casting
+
+
+        :param self: Set by Python.  No need to pass.
+        :return: a text automapper type
+        :example: A.column("paid").to_text()
+        """
+
+        from spark_auto_mapper.data_types.cast_to_type import (
+            AutoMapperCastToTypeDataType,
+        )
+        from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
+
+        return cast(
+            AutoMapperTextLikeBase, AutoMapperCastToTypeDataType(self, "string")
+        )
+
+    def to_type(self: _TAutoMapperDataType, type_: str) -> "AutoMapperDataTypeBase":
+        """
+        converts the value to the specified type
+
+
+        :param self: Set by Python.  No need to pass.
+        :param type_: type to convert the value to
+        :return: a text automapper type
+        :example: A.column("paid").to_text()
+        """
+
+        from spark_auto_mapper.data_types.cast_to_type import (
+            AutoMapperCastToTypeDataType,
+        )
+
+        return AutoMapperCastToTypeDataType(self, type_)
+
     # noinspection PyMethodMayBeStatic
     def join_using_delimiter(
         self: _TAutoMapperDataType, delimiter: str
@@ -690,6 +738,9 @@ class AutoMapperDataTypeBase:
         if self.children is None or not isinstance(self.children, list):
             return
 
+        for child in self.children:
+            assert isinstance(child, AutoMapperDataTypeBase), f"{type(child)}"
+
         children_properties: Dict[AutoMapperDataTypeBase, List[FieldNode]] = {
             v: v.get_fields(skip_null_properties=skip_null_properties)
             for v in self.children
@@ -929,7 +980,10 @@ class AutoMapperDataTypeBase:
         if isinstance(children, list) and len(children) > 0:
             child: "AutoMapperDataTypeBase"
             for index, child in enumerate(children):
-                assert child.column_name
+                assert isinstance(child, AutoMapperDataTypeBase), f"{type(child)}"
+                if not child.column_name:
+                    continue
+                assert child.column_name, f"No column name for {child}"
                 clean_child_name: str = PythonKeywordCleaner.from_python_safe(
                     child.column_name
                 )
