@@ -1,9 +1,10 @@
-from typing import Optional
+from typing import List, Optional, Union
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import expr
 
 from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
+from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
 
 
 class AutoMapperDataTypeExpression(AutoMapperArrayLikeBase):
@@ -12,7 +13,10 @@ class AutoMapperDataTypeExpression(AutoMapperArrayLikeBase):
         self.value: str = value
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         if isinstance(
             self.value, str
@@ -20,3 +24,9 @@ class AutoMapperDataTypeExpression(AutoMapperArrayLikeBase):
             return expr(self.value)
 
         raise ValueError(f"value: {self.value} is not str")
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return []
