@@ -1,4 +1,4 @@
-from typing import Generic, Optional, TypeVar, List, Union
+from typing import Generic, List, Optional, TypeVar, Union
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.utils import AnalysisException
@@ -35,7 +35,10 @@ class AutoMapperFirstValidColumnType(
         ]
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         column_spec = None
 
@@ -43,7 +46,9 @@ class AutoMapperFirstValidColumnType(
             # noinspection PyBroadException
             try:
                 column_spec = column.get_column_spec(
-                    source_df=source_df, current_column=current_column
+                    source_df=source_df,
+                    current_column=current_column,
+                    parent_columns=parent_columns,
                 )
             except Exception:
                 # By definition, if we are unable to resolve a column spec, for whatever reason, the column definition
