@@ -1,4 +1,4 @@
-from typing import TypeVar, Union, Generic, Optional, cast, List
+from typing import Generic, List, Optional, TypeVar, Union, cast
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import when
@@ -55,18 +55,27 @@ class AutoMapperIfNotNullDataType(
         )
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         column_spec = when(
             self.check.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             ).isNull(),
             self.when_null.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             ),
         ).otherwise(
             self.value.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             )
         )
 
