@@ -1,4 +1,4 @@
-from typing import TypeVar, Union, Generic, Optional, cast, List
+from typing import Generic, List, Optional, TypeVar, Union, cast
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import when
@@ -53,21 +53,32 @@ class AutoMapperIfNotNullOrEmptyDataType(
         )
 
     def get_column_spec(
-        self, source_df: Optional[DataFrame], current_column: Optional[Column]
+        self,
+        source_df: Optional[DataFrame],
+        current_column: Optional[Column],
+        parent_columns: Optional[List[Column]],
     ) -> Column:
         column_spec = when(
             self.check.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             ).isNull()
             | self.check.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             ).eqNullSafe(""),
             self.when_null_or_empty.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             ),
         ).otherwise(
             self.value.get_column_spec(
-                source_df=source_df, current_column=current_column
+                source_df=source_df,
+                current_column=current_column,
+                parent_columns=parent_columns,
             )
         )
 
@@ -77,17 +88,4 @@ class AutoMapperIfNotNullOrEmptyDataType(
     def children(
         self,
     ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
-        result: List[AutoMapperDataTypeBase] = []
-        if self.value is not None:
-            result = result + (
-                self.value.children
-                if isinstance(self.value.children, list)
-                else [self.value.children]
-            )
-        if self.when_null_or_empty is not None:
-            result = result + (
-                self.when_null_or_empty.children
-                if isinstance(self.when_null_or_empty.children, list)
-                else [self.when_null_or_empty.children]
-            )
-        return result
+        return self.value
