@@ -7,6 +7,10 @@ from pyspark.sql.types import StringType
 from pyspark.sql import Column
 
 from spark_auto_mapper.data_types.array_distinct import AutoMapperArrayDistinctDataType
+from spark_auto_mapper.data_types.exists import AutoMapperExistsDataType
+from spark_auto_mapper.data_types.nested_array_filter import (
+    AutoMapperNestedArrayFilterDataType,
+)
 from spark_auto_mapper.data_types.array_max import AutoMapperArrayMaxDataType
 from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
 from spark_auto_mapper.data_types.coalesce import AutoMapperCoalesceDataType
@@ -558,6 +562,30 @@ class AutoMapperHelpers:
             ),
         )
 
+    @staticmethod
+    def nested_array_filter(
+        array_field: AutoMapperColumnOrColumnLikeType,
+        inner_array_field: AutoMapperColumnOrColumnLikeType,
+        match_property: str,
+        match_value: AutoMapperColumnOrColumnLikeType,
+    ) -> AutoMapperNestedArrayFilterDataType:
+        """
+        Filters an array by searching an inner array for a certain value on a property of the inner array
+
+
+        :param array_field: outer array we want to return values from based on the inner array filter
+        :param inner_array_field: array we check for the existence of a value on one of its fields
+        :param match_property: the field name on the inner array to use for the check
+        :param match_value: a field containing the value we want to test against match property field. to access
+        the parent column the syntax '{parent}.field' can be used.
+        """
+        return AutoMapperNestedArrayFilterDataType(
+            array_field=array_field,
+            inner_array_field=inner_array_field,
+            match_property=match_property,
+            match_value=match_value,
+        )
+
     @staticmethod
     def filter(
         column: AutoMapperColumnOrColumnLikeType, func: Callable[[Column], Column]
@@ -577,6 +605,20 @@ class AutoMapperHelpers:
         # )
         return AutoMapperFilterDataType(column=column, func=func)
 
+    @staticmethod
+    def exists(
+        column: AutoMapperColumnOrColumnLikeType, func: Callable[[Column], Column]
+    ) -> AutoMapperExistsDataType:
+        """
+        Tests whether a predicate holds for one or more elements in the array
+
+
+        :param column: column to check
+        :param func: func to test against array
+        :return: a exists automapper type
+        """
+        return AutoMapperExistsDataType(column=column, func=func)
+
     @staticmethod
     def transform(
         column: AutoMapperColumnOrColumnLikeType, value: _TAutoMapperDataType
