@@ -8,8 +8,8 @@ from pyspark.sql.functions import lit, col
 from pyspark.sql.types import StringType
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_coalesce(spark_session: SparkSession) -> None:
@@ -42,7 +42,7 @@ def test_auto_mapper_coalesce(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
+    assert_compare_expressions(
         sql_expressions["my_column"],
         coalesce(
             col("b.last_name"),
