@@ -9,6 +9,7 @@ from pyspark.sql.functions import to_date
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_date_column_typed(spark_session: SparkSession) -> None:
@@ -42,8 +43,8 @@ def test_auto_mapper_date_column_typed(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["birthDate"]) == str(
-        col("b.date_of_birth").alias("birthDate")
+    assert_compare_expressions(
+        sql_expressions["birthDate"], col("b.date_of_birth").alias("birthDate")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
