@@ -8,8 +8,8 @@ from pyspark.sql.functions import lit
 from pyspark.sql.functions import coalesce, to_date
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_date_literal(spark_session: SparkSession) -> None:
@@ -40,7 +40,7 @@ def test_auto_mapper_date_literal(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
+    assert_compare_expressions(
         sql_expressions["birthDate"],
         coalesce(
             to_date(lit("1970-01-01"), format="y-M-d"),
