@@ -2,6 +2,8 @@ from pathlib import Path
 from typing import Dict
 
 from pyspark.sql import SparkSession, DataFrame, Column
+
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 from tests.conftest import clean_spark_session
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
@@ -33,7 +35,9 @@ def test_automapper_first(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(col("b.identifier[0]").alias("age"))
+    assert_compare_expressions(
+        sql_expressions["age"], col("b.identifier[0]").alias("age")
+    )
     result_df: DataFrame = mapper.transform(df=source_df)
 
     result_df.show(truncate=False)
