@@ -9,6 +9,7 @@ from pyspark.sql.types import StringType
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 from tests.conftest import clean_spark_session
 
 
@@ -47,13 +48,14 @@ def test_automapper_if_not_null_or_empty(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(
+    assert_compare_expressions(
+        sql_expressions["age"],
         when(
             col("b.my_age").isNull() | col("b.my_age").eqNullSafe(""),
             lit("100").cast(StringType()),
         )
         .otherwise(col("b.my_age"))
-        .alias("age")
+        .alias("age"),
     )
 
     result_df: DataFrame = mapper.transform(df=df)
