@@ -6,6 +6,7 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import lit
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.helpers.expression_comparer import assert_compare_expressions
 
 
 def test_auto_mapper_with_column_literal(spark_session: SparkSession) -> None:
@@ -36,7 +37,9 @@ def test_auto_mapper_with_column_literal(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["lname"]) == str(lit("last_name").alias("lname"))
+    assert_compare_expressions(
+        sql_expressions["lname"], lit("last_name").alias("lname")
+    )
 
     result_df: DataFrame = mapper.transform(df=df)
 
